@@ -13,11 +13,11 @@ if [ ! -z "$OVERC_DB_LINK" ] ; then
 fi
 
 # Logging
-#rm -f /var/run/{nginx,php5-fpm,zabbix/zabbix_server}.pid
-#LOGFILES=$(echo /var/log/{nginx/error,nginx/http.error,php5-fpm,supervisord,zabbix-server/zabbix_server}.log)
-#( umask 0 && truncate -s0 $LOGFILES ) && tail --pid $$ -n0 -F $LOGFILES &
+rm -f /var/run/nginx.pid
+LOGFILES=$(echo /var/log/{nginx/error,nginx/http.error,nginx/http.access,supervisord,uwsgi}.log)
+( umask 0 && truncate -s0 $LOGFILES ) && tail --pid $$ -n0 -F $LOGFILES &
 
 # Launch
 export OVERC_CONFIG=/etc/overc/server.ini
 export OVERC_DATABASE=mysql://$OVERC_DB_USER:$OVERC_DB_PASS@$OVERC_DB_HOST:$OVERC_DB_PORT/$OVERC_DB_NAME
-exec uwsgi /etc/uwsgi/overc.yml
+exec /usr/bin/supervisord -n >/dev/null 2>&1 # it's logging to a file anyway
